Import `process_ac` to use in scripts with your own data.

Run the GUI with
```
python -m molmag_ac_gui
```
to use the GUI for fitting relaxation times. Your own file with data of can be loaded and fitted in the "Analysis"-tab
if the file is formatted as

```
T1 tau1
T2 tau2
T3 tau3

...
```